<?php


	class GooglePlacesApiService {

		private $key;

		public function __construct( $key ) {
			$this->key = $key;
		}

		private function createHttpClient( $request_url ) {
			try {
				return wp_remote_retrieve_body( wp_remote_get( $request_url ) );

			} catch ( Exception $e ) {
				var_dump( $e );

				return null;
			}
		}

		public function getPlacesSearchResults( $request_params ) {
			$lat_long    = $this->getLongLat( $request_params['city'], $request_params['state'] );
			$radius      = $request_params['miles'] * 1600;
			$request_url = 'location=' . $lat_long['lat'] . ',' . $lat_long['long'];
			$request_url .= '&radius=' . $radius;
			$request_url .= '&type=' . $request_params['business_type'];
			$request_url .= '&keyword=' . $request_params['search_term'];

			$search_url = 'https://maps.googleapis.com/maps/api/place/nearbysearch/json?' . $request_url . '&key=' . $this->key;

			return $this->createHttpClient( $search_url );
		}

		public function getNextPage( $next_page_token ) {
			$next_page_url = 'https://maps.googleapis.com/maps/api/place/nearbysearch/json?pagetoken=' . $next_page_token . '&key=' . $this->key;

			return $this->createHttpClient( $next_page_url );
		}

		public function getPlacesDetailsResults( $place_id ) {
			$request_url = 'place_id=' . $place_id;
			$request_url .= '&fields=formatted_address,international_phone_number,website,url';

			$details_url = 'https://maps.googleapis.com/maps/api/place/details/json?' . $request_url . '&key=' . $this->key;

			return $this->createHttpClient( $details_url );
		}

		public function getPlaceAddressAndUrl( $place_id ) {
			$request_url = 'place_id=' . $place_id;
			$request_url .= '&fields=formatted_address,url';

			$details_url = 'https://maps.googleapis.com/maps/api/place/details/json?' . $request_url . '&key=' . $this->key;

			return $this->createHttpClient( $details_url );
		}

		private function getLongLat( $city, $state ) {
			$city         = str_replace( ' ', '+', $city );
			$state        = str_replace( ' ', '+', $state );
			$nominatimURL = 'https://nominatim.openstreetmap.org/search?&format=json&country=usa&limit=1&q=' . $city . '&city=' . $city . '&state=' . $state;
			$result       = json_decode( wp_remote_retrieve_body( wp_remote_get( $nominatimURL ) ) );

			return array(
				'lat'  => $result[0]->lat,
				'long' => $result[0]->lon
			);
		}

	}